<template>
    <#ibizinclude>
    ./CONTROL.html.ftl
    </#ibizinclude>
</template>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_DEFAULT.vue.ftl
</#ibizinclude>

<#assign self_content>
        /**
         * 数据视图
         *
         * @type {string}
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        @Prop() public viewdata!: string;

        /**
         * 查询集合
         *
         * @type {string}
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        @Prop() public searchAction?: string;

        /**
        * Api地址
        *
        * @type {string}
        * @memberof ${srfclassname('${ctrl.name}')}
        */
        public url: string = '${app.getPKGCodeName()?lower_case}/${de.getPSSystemModule().codeName?lower_case}/${de.codeName?lower_case}/${ctrl.codeName?lower_case}${srfclassname(ctrl.getControlType())?lower_case}/';
        
        /**
         * 面板状态订阅对象
         *
         * @private
         * @type {Subject<{action: string, data: any}>}
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public panelState: Subject<ViewState> = new Subject();
     
        /**
         * 数据数组
         *
         * @type []
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public items?: any = [];

        /**
         * 计数器
         *
         * @type number
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public count: number = 0;

        /**
         * 生命周期created
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public created(){
            if (this.viewState) {
                this.viewState.subscribe(({ tag, action, data }) => {
                    if (!Object.is(tag, this.name)) {
                        return;
                    }
                    if (Object.is(action, 'load')) {
                        this.load(data);
                    }
                    if (Object.is(action, 'save')) {
                        this.saveData(data);
                    }
                });
            }
        }

        /**
         * 加载方法
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public load(arg: any = {}, ): Promise<any> {
            return new Promise((resolve, reject) => {
                this.$http.post(this.url + this.searchAction, arg).then((response: any) => {
                    if (!response) {
                        return;
                    }
                    if (response) {
                        let data = JSON.parse(JSON.stringify(response.data.records));
                        if (data.length > 0) {
                            data.forEach((element: any) => {
                                Object.assign(element,this.viewdata)
                            });
                            this.items = data;
                        }
                        this.$emit("load",data);
                        resolve(response);
                    }
                });
            });
        }

        /**
         * 保存数据
         *
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public saveData(data?: any) {
            this.count = 0;
            if(this.items.length >0){
                this.panelState.next({ tag: 'meditviewpanel', action: 'save', data: data });
            }else{
                this.$emit("savecompleted",{action:'savecompleted'});
            }
        }
        /**
         * 新建
         *
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public addItem(): void {
            this.items.push({
                isSaved: 0
            });
            this.$emit('editformchange',{action:'add',args:{}});
        }

        /**
         * 删除方法
         *
         * @type {string}
         * @memberof ${srfclassname('${ctrl.name}')}
         */
         public deleteItem(item: any, index: number) {
				this.$prompt().show(
					{"message":"确认删除?",
					"confirm":() =>{
						if (item.srfkey && !Object.is(item.srfkey, '')) {
							this.panelState.next({ tag: 'meditviewpanel', action: 'remove', data: {srfkey:item.srfkey} });
						} else {
							this.items.splice(index, 1);
						}
						this.$emit('editformchange',{action:'remove', args:item});
					}}
				);
            }

        /**
         * 部件抛出事件
         *
         * @memberof ${srfclassname('${ctrl.name}')}
         */
        public viewDataChange($event:any){
            if($event){
                if(Object.is($event.action,'load')){
                    console.log('加载----');
                }
                if(Object.is($event.action,'save')){
                    this.count++;
                    if (this.items.length === this.count) {
                        this.$emit('savecompleted',{action:'savecompleted'});
                    }
                }
                if(Object.is($event.action,'remove')){
                    if ($event.data) {
                    let resultIndex = this.items.findIndex((value:any, index:any, arr:any) => {
                        return value.srfkey === $event.data.srfkey;
                    });
                    if (resultIndex !== -1) {
                        this.items.splice(resultIndex, 1);
                    }
                    }
                }   
            }
        }

</#assign>

<#assign self_header>
import { Subject } from 'rxjs';
import '@/assets/interface/viewState';
<#if ctrl.getPSControls?? && ctrl.getPSControls()??>

<#list ctrl.getPSControls() as subctrl>
<#if subctrl.getControlType() != 'TOOLBAR' && subctrl.getControlType() != 'CONTEXTMENU'>
    <#if subctrl.getPSDataEntity?? && subctrl.getPSDataEntity()??>
import view_${subctrl.getName()} from '@/widget/${srffilepath2(subctrl.getPSDataEntity().getCodeName())}/${srffilepath2(subctrl.getCodeName())}-${subctrl.getControlType()?lower_case}/${srffilepath2(subctrl.getCodeName())}-${subctrl.getControlType()?lower_case}.vue';
<#else>
import view_${subctrl.getName()} from '@/widget/app/${srffilepath2(subctrl.getCodeName())}-${subctrl.getControlType()?lower_case}/${srffilepath2(subctrl.getCodeName())}-${subctrl.getControlType()?lower_case}.vue';
</#if>
</#if>
</#list>
</#if>
import {Dialog} from 'vant'
</#assign>



<#ibizinclude>
../@MACRO/CONTROL/CONTROL_CONTAINER.vue.ftl
</#ibizinclude>

<style lang="less">
    <#ibizinclude>
    ./CONTROL.less.ftl
    </#ibizinclude>
</style>