<template>
    <#ibizinclude>
    ./CONTROL.html.ftl
    </#ibizinclude>
</template>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_DEFAULT.vue.ftl
</#ibizinclude>
<#assign self_header>
import { FormButtonModel, FormPageModel, FormItemModel, FromDRUIPartModel, FormPartModel, FormGroupPanelModel, FormRowItemModel, FormTabPageModel, FormTabPanelModel, FormUserControlModel } from '@/assets/form-detail';
import { Subject,Subscription } from 'rxjs';
import '@/assets/interface/viewState';
</#assign>
<#assign self_content>

    /**
     * 详情模型集合
     *
     * @type {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public detailsModel: any = {};

    /**
    * 是否展示表单内容
    *
    * @type {boolean}
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public isDisplayContent: boolean = false;

     /**
     * Api地址
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    public url: string = '${app.getPKGCodeName()?lower_case}/${de.getPSSystemModule().codeName?lower_case}/${de.codeName?lower_case}/${ctrl.codeName?lower_case}${srfclassname(ctrl.getControlType())?lower_case}/';

    /**
     * 初始化表单详情模型集合
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public initFormDetailsModel(): void {
        <#list ctrl.getAllPSDEFormDetails() as formdetail>
        Object.assign(this.detailsModel, {
            ${formdetail.name}: ${P.getPartCode(formdetail, 'DETAIL_MODEL').code}
        });
        </#list>
    }

     /**
     * 修改行为
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    @Prop() public updateAction?: string;

     /**
     * 加载草稿表单行为
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    @Prop() public loaddraftformAction?: string;

     /**
     * 删除行为
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    @Prop() public removeAction?: string;

     /**
     * 加载草稿行为
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    @Prop() public loaddraftAction?: string;

     /**
     * 加载行为
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    @Prop() public loadAction?: string;

     /**
     * 新建行为
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    @Prop() public createAction?: string;

    /**
     * 表单数据对象
     *
     * @type {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public data: any = {
        <#list ctrl.getPSDEFormItems() as item>
        ${item.getName()}: null,
        </#list>
    };

    /**
     * 初始化表单详情模型集合
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public created(){
        this.handleCreated();
    }

    /**
     * 执行created后的逻辑
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public handleCreated(){
        this.initFormDetailsModel();
        if (this.viewState) {
            this.viewState.subscribe(({ tag, action, data }) => {
                if (!Object.is(tag, this.name)) {
                    return;
                }
                if (Object.is('autoload', action)) {
                    this.autoLoad(data);
                }
                if (Object.is('load', action)) {
                    this.load(data);
                }
                if (Object.is('loaddraft', action)) {
                    this.loadDraft(data);
                }
            });
        }
    }

    /**
     * 自动加载
     *
     * @param {*} [arg={}]
     * @returns {void}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public autoLoad(arg: any = {}): void {
        if (arg.srfkey && !Object.is(arg.srfkey, '')) {
            this.load(arg);
            return;
        }
        if (arg.srfkeys && !Object.is(arg.srfkeys, '')) {
            Object.assign(arg, { srfkey: arg.srfkeys });
            this.load(arg);
            return;
        }
        this.loadDraft(arg);
    }

    /**
     * 加载
     *
     * @private
     * @param {*} [opt={}]
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    private load(opt: any = {}): void {
        const arg: any = { ...opt };
        this.$http.get(this.url + this.loadAction, arg).then((response: any) => {
            if (response) {
                const data = response;
                this.fillForm(data);
                this.$emit('load',data);
            }
        }).catch((error: any) => {
            this.$notify({ type: 'danger', message: '错误,' + error.info });
        });
    }

    /**
     * 加载草稿
     *
     * @param {*} [opt={}]
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public loadDraft(opt: any = {}): void {
        const arg: any = { ...opt };
        let post: Promise<any>;
        if (!arg.srfsourcekey || Object.is(arg.srfsourcekey, '')) {
            post = this.$http.post(this.url + this.loaddraftAction, arg);
        } else {
            post = this.$http.post(this.url + this.loaddraftformAction, arg);
        }
        post.then((response: any) => {
            if (response) {
                const data = response;
                this.fillForm(data);
                this.$emit('load',data);
            }
        }).catch((error: any) => {
            this.$notify({ type: 'danger', message: '错误,' + error.info });
        });
    }

    /**
     * 值填充
     *
     * @param {*} [_datas={}]
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    public fillForm(_datas: any = {}): void {
        Object.keys(_datas).forEach((name: string) => {
            if (this.data.hasOwnProperty(name)) {
                this.data[name] = _datas[name];
            }
        });
    }

    /**
     * 重置
     *
     * @param {*} [opt={}]
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public onReset(){
        if(Object.keys(this.data).length >0){
            Object.keys(this.data).forEach((item:any) =>{
                this.data[item]=null;
            })
        }
    }
    
    /**
     * 搜索
     *
     * @param {*} [opt={}]
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public onSearch(){
        this.$emit('search',this.data);
    }

  /**
   * 切换样式
   *
   * @param {*} [opt={}]
   * @memberof ${srfclassname('${ctrl.codeName}')}
   */
  public toggleDisplay() {
    this.isDisplayContent = !this.isDisplayContent;
  }

        /**
        * 表单项值改变
        *
        * @memberof Mobeditform
        */
        public valueChange(name:string,value:any){
            let oldValue = JSON.parse(JSON.stringify(this.data[name]));
            this.data[name] = value;
        }
</#assign>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_CONTAINER.vue.ftl
</#ibizinclude>

<style lang="less">
    <#ibizinclude>
    ./CONTROL.less.ftl
    </#ibizinclude>
</style>