<template>
    <#ibizinclude>
    ./CONTROL.html.ftl
    </#ibizinclude>
</template>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_DEFAULT.vue.ftl
</#ibizinclude>

<#assign self_content>
    
    /**
    * 数据选择视图选中项
    *
    * @type {any}
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    @Prop() public selectedData?:any;

    /**
    * 跳转变量
    *
    * @type number
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public active: number = 0;
    
    /**
    * 节点数组
    *
    * @type Array<any>
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public nodeArray: Array<any> = [];
    
    /**
    * 选中数组
    *
    * @type Array<any>
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public checkedList: Array<any> = [];
    
    /**
    * 选中数据
    *
    * @type Array<any>
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public checkedData: Array<any> = [];

    /**
    * 是否可以选择
    *
    * @type {string}
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    @Prop({default:false}) public isOptional?: boolean;

    /**
    * 节点导航视图映射
    *
    * @type any
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public nodeView: any = {
    <#list ctrl.getPSDETreeNodes() as node>
        <#if node.getNavPSAppView?? && node.getNavPSAppView()??>
        '${node.getNodeType()}':{hasView: true, viewName: 'view-${node.getNavPSAppView().getName()?lower_case}'},
        <#else>
        '${node.getNodeType()}':{hasView: false},       
        </#if>
    </#list>
    };

    /**
    * Api地址
    *
    * @type {string}
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public url: string = '${app.getPKGCodeName()?lower_case}/ctrl/${ctrl.codeName?lower_case}${srfclassname(ctrl.getControlType())?lower_case}view/';
    
    /**
    * 初始化方法
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public created() {
        this.handleCreated();
    }

    /**
    * 执行created后的逻辑
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public handleCreated(){
        if (this.viewState) {
            this.viewState.subscribe(({ tag, action, data }) => {
                if (!Object.is(tag, this.name)) {
                    return;
                }
                if (Object.is(action, 'load')) {
                    this.load(data);
                }  
                if (Object.is(action, 'save')) {
                    this.$emit("change",this.checkedData);
                }                
            });
        }
        if(this.selectedData){
            this.selectedData.forEach((val:any, idx:any, array:any) => {
                this.checkedList.push(val.srfkey);
            });
        }
    }

    /**
    * 数据加载
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public load(data:any) {
        const param: any = {
        srfnodeid: data && data.id ? data.id : encodeURI('#'),
        };
        this.$http.get(this.url+"getnodes",param).then((res) => {
            this.nodeArray.push(res.data);
            this.active = this.nodeArray.length-1;
        });
    }

    /**
    * 跳转方法
    *
    * @param haschild 是否有子节点
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public show(node:any){
        if(!node.leaf){
            this.load(node);
        }else{
            this.openModal(node);    
        }
    }

    /**
    * 删除节点
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public deleteNode(){
        if(this.active == (this.nodeArray.length-2)){
            this.nodeArray.splice(this.nodeArray.length-1, 1); 
        }
    }

    /**
    * 选中切换方法
    *
    * @param node 节点数据
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public toggle(node:any){
        let index = this.checkedList.indexOf(node.srfkey);
        if(Object.is(index,-1)){
            this.checkedList.push(node.srfkey);
            this.checkedData.push(node);
        }else{
            this.checkedList.splice(index,1);
            this.checkedData.splice(index,1);
        }
    }

    /**
     * 打开编辑视图
     *
     * @param any 节点对象
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public openModal(node: any = {}) {
        let nodeType = this.nodeView[node.id.split(";")[0]];
        if(nodeType.hasView){
            let modalSubject = this.$modal({
                componentName: nodeType.viewName,
                viewdata:JSON.stringify({ srfkey: node.srfkey })
            }).show();
            modalSubject.subscribe((res: any) => {
                if (res) {
                    return Promise.resolve(res);
                }
            });
        }else{
            console.log("编辑视图未配置");
        }
    }

</#assign>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_CONTAINER.vue.ftl
</#ibizinclude>

<style lang="less">
    <#ibizinclude>
    ./CONTROL.less.ftl
    </#ibizinclude>
</style>